<?php
/**
 * @file
 * Defines personalization fragment for panel pane.
 */

/**
 * Personalization fragment for panel pane.
 */
class AuthcachePanelsPaneFragment implements AuthcacheP13nFragmentInterface, AuthcacheP13nFragmentLoaderInterface, AuthcacheP13nFragmentAccessInterface {
  protected $displayId;
  protected $paneId;

  /**
   * Construct new pane fragment.
   */
  public function __construct($display_id, $pane_id) {
    $this->displayId = $display_id;
    $this->paneId = $pane_id;
  }

  /**
   * {@inheritdoc}
   */
  public function load($params, $context) {
    ctools_include('plugins', 'panels');
    ctools_include('content');

    $display = panels_load_display($this->displayId);

    if (!$display) {
      throw new AuthcacheP13nRequestNotFound();
    }

    if (!isset($display->content[$this->paneId])) {
      throw new AuthcacheP13nRequestNotFound();
    }

    // Assign page manager context and arguments prepared by a context
    // provider.
    $display->context = array();
    if (!empty($context['panels']['context'])) {
      $display->context = $context['panels']['context'];
    }

    $display->args = array();
    if (!empty($context['panels']['arguments'])) {
      $display->args = $context['panels']['arguments'];
    }

    // Load renderer.
    $renderer = panels_get_renderer_handler($display->renderer, $display);
    if (!$renderer) {
      throw new AuthcacheP13nRequestNotFound();
    }

    return array(
      $this->paneId => $renderer,
    );
  }

  /**
   * {@inheritdoc}
   *
   * @see panels_renderer_standard::prepare_panes()
   */
  public function check($account, $pane_id, $renderer, $context) {
    $display = $renderer->display;
    $pane = $display->content[$pane_id];

    return panels_pane_access($pane, $display);
  }

  /**
   * {@inheritdoc}
   *
   * @see panels_renderer_standard::render_pane()
   */
  public function render($pane_id, $renderer, $context) {
    $result = '';

    $display = $renderer->display;
    $pane = $display->content[$pane_id];

    if ($pane->shown) {
      $content = $renderer->render_pane_content($pane);
      $result = render($content->content);
    }

    return $result;
  }
}
